#
# spec file for package gamemode
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 Matthias Bach <marix@marix.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gamemode
Version:        1.8.2
Release:        1.2
Summary:        Daemon/library combo for changing Linux system performance on demand
License:        BSD-3-Clause
Group:          Amusements/Games/Other
URL:            https://github.com/FeralInteractive/gamemode
Source0:        %{URL}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{URL}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        gamemode-rpmlintrc
Source3:        README.openSUSE
Source4:        baselibs.conf
Source5:        feral.keyring
BuildRequires:  cmake
BuildRequires:  libinih-devel
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(dbus-1)
# Yes, it needs both
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
# We need to explicitly define the dependency as this is used via
# LD_PRELOAD from a shell script and thus cannot be inferred.
Requires:       libgamemodeauto0
Provides:       gamemoded:%{_bindir}/gamemoderun
Provides:       gamemoded:%{_bindir}/gamemodelist

%description
GameMode is a daemon/lib combo for Linux that allows games to request
a set of optimisations be temporarily applied to the host OS.

GameMode was designed primarily as a stop-gap solution to problems
with the Intel and AMD CPU powersave or ondemand governors, but is
now able to launch custom user defined plugins, and is intended to be
expanded further, as there are a wealth of automation tasks one might
want to apply.

For applications that don't implement the GameMode activation themselves,
you can toggle the GameMode by running them via the gamemoderun command.

    gamemoderun ./game

For Steam games this can be done by editing the launch options:

    gamemoderun %%command%%

Note that some functionalities, like modifying the CPU governor, require
the user to be in the priviledged "gamemode" group.

%package -n gamemoded
Summary:        The GameMode daemon required by GameMode enabled games
Group:          Amusements/Games/Other
Recommends:     libgamemode
Suggests:       gamemode
Suggests:       libgamemodeauto
%sysusers_requires

%description -n gamemoded
GameMode is a daemon/lib combo for Linux that allows games to request
a set of optimisations be temporarily applied to the host OS.

The GameMode daemon is installed as a D-Bus Service and will start
automatically on first access by a client.

%package -n libgamemode0
Summary:        GameMode client library
Group:          System/Libraries
Requires:       gamemoded
%systemd_requires

%description -n libgamemode0
GameMode is a daemon/lib combo for Linux that allows games to request
a set of optimisations be temporarily applied to the host OS.

Libgamemode is the client library used by games or libgamemodeauto to
talk to the GameMode daemon.

%package -n libgamemodeauto0
Summary:        Helper library allowing to equip any game with GameMode support
Group:          System/Libraries
Requires:       libgamemode0

%description -n libgamemodeauto0
GameMode is a daemon/lib combo for Linux that allows games to request
a set of optimisations be temporarily applied to the host OS.

Libgamemodeauto allows you to use GameMode with any Game by
preloading it into the game.

    LD_PRELOAD=%{_libdir}/libgamemodeauto.so.0 ./game

For Steam games this can be done by editing the launch options:

    LD_PRELOAD=$LD_PRELOAD:%{_libdir}/libgamemodeauto.so.0 %%command%%

Nowadays this however can be easier done by using the gamemoderun command
from the gamemode package.

%package -n libgamemode-devel
Summary:        Headers for compiling games using GameMode
Group:          Development/Libraries/C and C++
Requires:       libgamemode0 = %{version}
Requires:       libgamemodeauto0 = %{version}

%description -n libgamemode-devel
GameMode is a daemon/lib combo for Linux that allows games to request
a set of optimisations be temporarily applied to the host OS.

This package contains the headers required to compile games with
built-in GameMode support.

%prep
%autosetup -p1

cp %{SOURCE3} .

%build
%meson -Dwith-examples=false
%meson_build

%check
%meson_test

%install
%meson_install

# Fix gamemode PolKit rules being overriden by default rules
mv %{buildroot}/%{_datadir}/polkit-1/rules.d/gamemode.rules %{buildroot}/%{_datadir}/polkit-1/rules.d/40-gamemode.rules

%post -n libgamemode0 -p /sbin/ldconfig
%postun -n libgamemode0 -p /sbin/ldconfig
%post -n libgamemodeauto0 -p /sbin/ldconfig
%postun -n libgamemodeauto0 -p /sbin/ldconfig

%post -n gamemoded
%sysusers_create %{name}.conf

%files
%{_bindir}/gamemodelist
%{_bindir}/gamemoderun
%{_mandir}/*/gamemodelist*
%{_mandir}/*/gamemoderun*
%license LICENSE.txt

%files -n gamemoded
%{_bindir}/gamemoded
%{_libexecdir}/cpugovctl
%{_libexecdir}/cpucorectl
%{_libexecdir}/gpuclockctl
%{_libexecdir}/procsysctl
%{_userunitdir}/gamemoded.service
%{_datadir}/polkit-1/actions/com.feralinteractive.GameMode.policy
%{_datadir}/polkit-1/rules.d/40-gamemode.rules
%{_datadir}/dbus-1/services/com.feralinteractive.GameMode.service
%{_datadir}/metainfo/io.github.feralinteractive.gamemode.metainfo.xml
%{_mandir}/*/gamemoded*
%{_sysusersdir}/%{name}.conf
%dir %{_sysconfdir}/security/limits.d
%config(noreplace) %{_sysconfdir}/security/limits.d/10-gamemode.conf
%doc example/gamemode.ini README.openSUSE
%license LICENSE.txt

%files -n libgamemode0
%{_libdir}/libgamemode.so.0*
%license LICENSE.txt

%files -n libgamemodeauto0
%{_libdir}/libgamemodeauto.so.0*
%license LICENSE.txt

%files -n libgamemode-devel
%{_includedir}/gamemode_client.h
%{_libdir}/libgamemode.so
%{_libdir}/libgamemodeauto.so
%{_libdir}/pkgconfig/gamemode*
%{_libdir}/pkgconfig/libgamemode*
%license LICENSE.txt

%changelog
* Tue Aug 20 2024 Matthias Bach <marix@marix.org> - 1.8.2
- Update to version 1.8.2
  * Fix idle inhibitor closing bus connection too early
  * Fix hybrid CPU core pinning
  * Fix unreadable process maps in gamemodelist
  * Fixed crash if dbus is not accesible
  * Various bugfixes and improvements to documentation
* Thu Dec 21 2023 Matthias Bach <marix@marix.org>
- Fix package setting a wrong mode for /etc/security/limits.d.
- Drop unused rpmlint filter.
* Wed Dec 13 2023 Matthias Bach <marix@marix.org>
- Fix GameMode's PolicyKit rules not applying.
* Wed Dec 13 2023 Matthias Bach <marix@marix.org>
- Update to version 1.8.1
  * Fix syntax error in polkit rules.
* Fri Dec  8 2023 Matthias Bach <marix@marix.org> - 1.8
- Update to version 1.8
  * Requires users to be a member of the "gamemode" group to
    utilise priviledged functionality like modifying the CPU
    governor.
  * Adds CPU core pinning and parking capability.
  * Allows disabling the Linux kernel split lock mitigation.
  * Fixes building when pidfd_open is available.
  * Unifies privileged group configuration between pam, systemd,
    and polkit.
  * Various other bugfixes and improved default configuration
- Drop workaround for problematic pidfd_open dection on Tumbleweed
  now that compilation with pidfd_open is fixed upstream.
- Drop no longer required only-build-shared-library.patch.
* Wed May 10 2023 Matthias Bach <marix@marix.org> - 1.7
- Add a new gamemode binary package
  * This provides gamemoderun and gamemodelist commands previously
    provided via the gamemoded package. However, these actually
    require libgamemodeauto0 which was missed.
  * You can now install the gamemode package to get the full set
    of GameMode functionality. Not being able to do this admittedly
    was confusing as was reported in bsc#1211086.
- Add feral.keyring to enable verifying the source signature.
* Sat Sep  3 2022 Matthias Bach <marix@marix.org> - 1.7
- Add a workaround for building on Tumbleweed where detection of
  the pidfd_open function does not work properly.
* Fri Jul 22 2022 Matthias Bach <marix@marix.org> - 1.7
- Update to version 1.7
  * New utility: gamemode
  * Run executables from PATH instead of /usr/bin
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.6.1
  * Use inih r53
  * Minor metainfo improvements
- Use SourceUrl and signature
* Wed Sep 23 2020 marix@marix.org
- Update to version 1.6:
  * Improved man pages
  * Bug fixes
- Added only-build-shared-library.patch.
- Drop special handling for no longer supported Leap 42.
* Thu Jan 23 2020 marix@marix.org
- Update to version 1.5:
  * Introduce a new pidfd based set of D-Bus APIs.
  * Dynamically change governor on integrated GPUs for improved
    performance.
  * Various other fixes and improvements.
* Tue Jul 23 2019 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to version 1.4
  * Add new D-Bus methods/properties for use by external tools
    such as the GameMode GNOME Shell extension.
  * Fix I/O priority and niceness optimisations to apply to the
    whole process rather than just the thread that
    requests GameMode.
  * gamemoded will now automatically reload the configuration
    file when it is changed and update optimisations on
    current clients.
  * Add support for using the client library inside Flatpak by
    communicating with the daemon via a portal.
  * Client library now uses libdbus rather than sd-bus.
  * Fix gamemoderun to use the correct library path depending on
    whether the app is 32-bit or 64-bit.
  * Support the GAMEMODERUNEXEC environment variable to specify
    an extra wrapper command for games launched with gamemoderun
    (e.g. a hybrid GPU wrapper such as optirun).
  * Various other fixes and improvements.
- Removed gpuctl-fixes.patch already included in 1.4
- Added "BuildRequires:  pkgconfig(dbus-1)" to spec file which
  is needed by version 1.4
* Wed May 22 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the gamemode build requirement.
* Tue Apr  9 2019 Matthias Bach <marix@marix.org>
- Update to version 1.3.1
  * Disables screensaver when the game is running.
  * New `gamemoderun` script to run games in GameMode which don't
    support it themselves.
  * Add GPU managment capabilities.
- Removed hardening.patch already included in 1.3.
- Add gpuctl-fixes.patch hardening the new GPU features.
* Sat Mar 16 2019 Matthias Bach <marix@marix.org>
- Include the baselibs.conf in the source RPM.
* Wed Mar 13 2019 Andreas Prittwitz <m4ng4n@gmx.de>
- Add baselibs.conf to also build -32bit packages for the x86-64
  arch as they are required by 32bit games in wine.
  See https://github.com/FeralInteractive/gamemode/issues/25.
* Thu Aug 16 2018 jengelh@inai.de
- Wrap descriptions. Add missing Group: lines.
- Use noun phrase in summary.
* Mon Aug 13 2018 marix@marix.org
- Add hardening.patch: This backports bugfixes and hardenings
  resulting from the Factory-inclusion security review and already
  accepted by upstream.
- Stop suppressing linter warning for the PolicyKit priviledge
  escalation. This has been properly handled via boo#1093979 now.
- Suppress false positive lintian caused by a %% symbol in the
  description of the libgamemodeauto library.
* Tue Jul 24 2018 marix@marix.org
- Update to version 1.2:
  + Store the initial governor state on mode enter
  + Config now supports defaultgov and desiredgov
  + Add support for renice-ing games to a higher priority (renice
    config option)
  + Make libraries properly versioned.
- Gamemoded is now run as a Systemd service in the user session
  but still activated via D-Bus.
* Sat May 19 2018 marix@marix.org
- Fix compilation on Leap 42.3.
* Tue May 15 2018 marix@marix.org
- Add Documentation files:
  + License
  + Sample configuration file
  + README.openSUSE documenting how to apply configuration
* Tue May 15 2018 marix@marix.org
- Replace Systemd unit by a D-Bus service.
  + The Systemd unit does not work on openSUSE as it lacks access
    to D-Bus.
  + The D-Bus service is zero configuration for the user.
* Sat May 12 2018 marix@marix.org
- Work around Leap 42.3's default compiler being to old.
* Sat May 12 2018 marix@marix.org
- Initial experimental package version.
  + Provides the GameMode daemon
  + Provides the auto-GameMode library
  + Provides a devel package with the GameMode client header
